@@ -25,8 +25,8 @@ class InventoryMain(BaseModelTimeAndDeleted):
     """
     id = CharField("id", primary_key=True, default=get_uuid4_hex, blank=True, max_length=128)
     number = CharField("盘点序列号", max_length=128, db_index=True, unique=True)
-    distribute_status = CharField("盘点位置", max_length=128, blank=True)
-    distribute_status_name = CharField("盘点位置名称", max_length=128, blank=True)
+    distribute_status = CharField("盘点位置", max_length=128, blank=True, null=True)
+    distribute_status_name = CharField("盘点位置名称", max_length=128, blank=True, null=True)
     inventory_user_id = CharField("盘点人 id", max_length=128, blank=True)
     inventory_username = CharField("盘点人姓名", max_length=128, blank=True)
     inventory_user_displayname = CharField("盘点人昵称", max_length=128, blank=True)
@@ -42,6 +42,10 @@ class InventoryMain(BaseModelTimeAndDeleted):
     if_help = BooleanField("是否是多人盘点", null=True, default=0, db_index=True)
     status = CharField("盘点状态", max_length=16, default=InventoryMainStatus.INIT, db_index=True)
 
+    store_code = CharField("货架位置编码", max_length=128, null=True, db_index=True)
+    store_number = CharField("货架位置", max_length=128, null=True)
+    store_name = CharField("货架位置名称", max_length=128, null=True)
+
     @property
     def helps(self):
         return InventoryHelp.objects.filter(main_id=self.id).order_by('-help_start_time', 'shelf_number')
@@ -63,9 +67,9 @@ class InventoryDetail(BaseModelTimeAndDeleted):
     id = CharField("id", primary_key=True, default=get_uuid4_hex, blank=True, max_length=128)
     main_id = CharField("盘点主表 id", db_index=True, blank=True, max_length=128)
     main_number = CharField("盘点序列号", max_length=128, blank=True)
-    distribute_id = CharField("发货单 id", max_length=100, blank=True, db_index=True)
-    distribute_number = CharField("发货单号", max_length=100, blank=True)
-    distribute_name = CharField("发货单名称", max_length=100, blank=True)
+    distribute_id = CharField("发货单 id", max_length=100, blank=True, db_index=True, null=True)
+    distribute_number = CharField("发货单号", max_length=100, blank=True, null=True)
+    distribute_name = CharField("发货单名称", max_length=100, blank=True, null=True)
     order_id = PositiveIntegerField("订单 id", blank=True, db_index=True)
     order_number = CharField("订单号", max_length=128, blank=True)
     shop_id = PositiveIntegerField("专柜 id", blank=True)
@@ -92,6 +96,12 @@ class InventoryDetail(BaseModelTimeAndDeleted):
     checked_user_id = CharField("实际盘点人", max_length=64, null=True)
     checked_shelf_number = CharField("实际盘点位置", max_length=64, null=True)
 
+    busi_id = CharField("业务单ID", max_length=40, db_index=True, null=True)
+    busi_number = CharField("业务单number", max_length=64, db_index=True, null=True)
+    # busi_name 目前只有发货单有 distribute_name
+    busi_name = CharField("业务单Name", max_length=64, null=True)
+    busi_type = CharField("业务单类型", max_length=16, db_index=True, null=True)
+
     @property
     def notes(self):
         return InventoryNote.objects.filter(detail_id=self.id).order_by('-created_time')
@@ -138,9 +148,9 @@ class InventoryNote(BaseModelTimeAndDeleted):
 
     main_id = CharField("盘点主表 id", db_index=True, blank=True, max_length=128)
     main_number = CharField("盘点序列号", max_length=128, blank=True)
-    distribute_id = CharField("发货单 id", max_length=100, blank=True, db_index=True)
-    distribute_number = CharField("发货单号", max_length=100, blank=True)
-    distribute_name = CharField("发货单名称", max_length=100, blank=True)
+    distribute_id = CharField("发货单 id", max_length=100, blank=True, db_index=True, null=True)
+    distribute_number = CharField("发货单号", max_length=100, blank=True, null=True)
+    distribute_name = CharField("发货单名称", max_length=100, blank=True, null=True)
 
     note_user_id = CharField("备注人 id", max_length=128, blank=True)
     note_username = CharField("备注人姓名", max_length=128, blank=True)
@@ -148,6 +158,12 @@ class InventoryNote(BaseModelTimeAndDeleted):
     note_time = DateTimeField("处理时间")
     message = CharField("处理意见", max_length=512, blank=True)
 
+    busi_id = CharField("业务单ID", max_length=40, db_index=True, null=True)
+    busi_number = CharField("业务单number", max_length=64, db_index=True, null=True)
+    # busi_name 目前只有发货单有 distribute_name
+    busi_name = CharField("业务单Name", max_length=64, null=True)
+    busi_type = CharField("业务单类型", max_length=16, db_index=True, null=True)
+
     class Meta:
         verbose_name = '盘点备注表'
         app_label = APP_LABEL
@@ -256,8 +272,8 @@ class StorageRecord(BaseModelTimeAndDeleted):
     """
     id = CharField("库存 id", primary_key=True, default=get_uuid4_hex, max_length=128, blank=True)
 
-    distribute_id = CharField("发货单id", max_length=128, db_index=True)
-    distribute_number = CharField("发货单号", max_length=128, db_index=True)
+    distribute_id = CharField("发货单id", max_length=128, db_index=True, null=True)
+    distribute_number = CharField("发货单号", max_length=128, db_index=True, null=True)
 
     order_id = CharField("订单 id ", max_length=128, db_index=True)
     order_number = CharField("订单号", max_length=128, db_index=True)
