@@ -202,6 +202,14 @@ class Distributeline(BaseModelTimeAndDeleted):
     deliver_time_type = models.CharField("发货时间类型", max_length=32, choices=DeliverTimeType.DELIVERTIME_TYPE_CHOICES, blank=True, null=True)
     # deliver_relative_time 相对时间(单位：天)
     deliver_relative_time = models.DecimalField("相对时间", decimal_places=2, max_digits=12, blank=True, null=True)
+    ecard_info = None
+
+    # 2022.08 订单冗余sell_type
+    sell_type = models.CharField("sell_type", max_length=32, blank=True, null=True, db_index=True)
+
+    # 2022.11 发货仓
+    outstorage_id = models.CharField("发货仓", max_length=40, blank=True, null=True)
+    retstorage_id = models.CharField("退货仓", max_length=40, blank=True, null=True)
 
     class Meta:
         app_label = APP_LABEL
