@@ -135,17 +135,20 @@ class ExpressName:
     SF = 'sf'
     YZ = 'yz'
     ZTO = 'zto'
+    JD = 'jd'
 
     CODE_2_system_codes = {
         SF: [Partner.SF, Partner.SFTCJS],
         YZ: [Partner.YZPY],
-        ZTO: [Partner.ZTO]
+        ZTO: [Partner.ZTO],
+        JD: [Partner.JD],
     }
 
     CODE_2_NAME_MAP = {
         SF: "顺丰",
         YZ: "邮政",
         ZTO: "中通",
+        JD: "京东",
     }
 
     EXPRESS_NAME_INFOS = [
@@ -161,4 +164,8 @@ class ExpressName:
             "name": CODE_2_NAME_MAP[ZTO],
             "code": ZTO,
         },
+        {
+            "name": CODE_2_NAME_MAP[JD],
+            "code": JD,
+        },
     ]
